@@ -7,19 +7,20 @@ echo "Installing Cluster-Telemetry"
 
 echo $
 if [ "$(echo "intel123" | sudo docker ps -q -f name=^prometheus$)" ]; then
-    echo "Cluster-Telemetry already running"
+    echo -e "\e[1;32m\nCluster-Telemetry already running\e[0m"
     echo -e "To stop run command: '\e[1;3;4;33mdc app-services cluster-telemetry stop $1\e[0m'"
 else
-    echo "Installing Cluster-Telemetry service"
+    echo -e "\e[1;32m\nInstalling Cluster-Telemetry service\e[0m"
     export HOST_IP=$(hostname -I | cut -d' ' -f1)
-    python_path=$(python3 -m site --user-site)
+    ver=$(python3 --version | grep Python | awk '{print $2}' | xargs printf '%0.1f\n')
     if [ $1=="all-services" ]; then      
-         sudo -E docker-compose -f $python_path/src/scripts/app-services/cluster-telemetry/docker-compose-app-service.yaml  up -d --build grafana prometheus node-exporter    
+         sudo -E docker-compose -f /usr/local/lib/python$ver/dist-packages/src/scripts/app-services/cluster-telemetry/docker-compose-app-service.yaml  up -d --build grafana prometheus node-exporter    
+         sudo docker ps 
     fi
 fi
 
-echo "\nIf cluster-telemetry is working fine.Then check metrics by using Grafana"
+echo "If cluster-telemetry is working fine.Then check metrics by using Grafana"
 
 echo -e "\e[1;32m\n********* Grafana URL **************\e[0m"
 echo -e "\e[1;36mGrafana Dashboard is available in the below URL\e[0m"
-echo -e "\e[1;33mhttp://$HOST_IP:3000 \e[0m\n"
+echo -e "\e[1;33mhttp://$HOST_IP:3212\e[0m\n"
